
/*
const float Eta = 2.42;
const float FresnelPower = 2.5; */

// NVIDIA
const float Eta =1.2;
const float FresnelPower = 1.2; 

const float F  = ((1.0-Eta) * (1.0-Eta)) / ((1.0+Eta) * (1.0+Eta));

uniform samplerCube Cubemap;
uniform sampler2D texScratch;

uniform int useScratch;

varying vec3 i;
varying vec3 normal;

varying mat3 transposeNormalMatrix;

varying vec4 diffuse;


void main()
{

	vec3 Reflect;
	vec3 Refract;

	vec3 n = normalize(normal);
	
	Reflect = reflect(i, n);
    Reflect = transposeNormalMatrix * Reflect;

	Refract = refract(i, n, Eta);
    Refract = transposeNormalMatrix * Refract;

	float Ratio   = F + (1.0 - F) * pow((1.1 - dot(-i, n)), FresnelPower);

    vec4 refractColor = vec4(textureCube(Cubemap, Refract));
    vec4 reflectColor = vec4(textureCube(Cubemap, Reflect));

	refractColor.a=1.0;
	reflectColor.a=1.0;

	vec4 color   = mix(refractColor, reflectColor, Ratio);

	vec4 scratchColor=vec4(0.7,0.7,0.7,1.0);
	
	if (useScratch==1) {
		scratchColor= texture2D(texScratch,gl_TexCoord[1].st);
	}

	color.rgb=(color.rgb+diffuse.rgb*0.7)*scratchColor.rgb;

	gl_FragColor =vec4(color.rgb,1.0);
}
